@@ -210,6 +210,15 @@ describe "DB#create_table" do
     @db.sqls.must_equal ['CREATE TABLE cats (id integer AUTOINCREMENT, cat_id integer, CONSTRAINT foo PRIMARY KEY (id), CONSTRAINT baz FOREIGN KEY (cat_id) REFERENCES cats(foo_id) ON DELETE CASCADE ON UPDATE RESTRICT DEFERRABLE INITIALLY DEFERRED, CONSTRAINT bar UNIQUE (cat_id))']
   end
 
+  it "should handling splitting named column constraints into table constraints if unsupported using :primary_key and :unique options with hash values" do
+    def @db.supports_named_column_constraints?; false end
+    @db.create_table(:cats) do
+      primary_key :id, :primary_key=>{:name=>:foo, :deferrable=>true}
+      foreign_key :cat_id, :cats, :unique=>{:name=>:bar, :deferrable=>true}, :foreign_key_constraint_name=>:baz, :deferrable=>true, :key=>:foo_id, :on_delete=>:cascade, :on_update=>:restrict
+    end
+    @db.sqls.must_equal ['CREATE TABLE cats (id integer AUTOINCREMENT, cat_id integer, CONSTRAINT foo PRIMARY KEY (id) DEFERRABLE INITIALLY DEFERRED, CONSTRAINT baz FOREIGN KEY (cat_id) REFERENCES cats(foo_id) ON DELETE CASCADE ON UPDATE RESTRICT DEFERRABLE INITIALLY DEFERRED, CONSTRAINT bar UNIQUE (cat_id) DEFERRABLE INITIALLY DEFERRED)']
+  end
+
   it "should accept and literalize default values" do
     @db.create_table(:cats) do
       integer :id, :default => 123
@@ -296,6 +305,26 @@ describe "DB#create_table" do
     @db.sqls.must_equal ["CREATE TABLE cats (id integer PRIMARY KEY DEFERRABLE INITIALLY DEFERRED, i integer PRIMARY KEY DEFERRABLE INITIALLY IMMEDIATE, j integer PRIMARY KEY NOT DEFERRABLE)"]
   end
   
+  it "should handle :unique option with hash value for options for unique constraint" do
+    @db.create_table(:cats) do
+      integer :id, :unique=>{:name=>:u1, :deferrable=>true}
+      integer :i, :unique=>{:name=>:u2, :deferrable=>:immediate}
+      integer :j, :unique=>{:deferrable=>false}
+      integer :k, :unique=>{:name=>:u3}
+    end
+    @db.sqls.must_equal ["CREATE TABLE cats (id integer CONSTRAINT u1 UNIQUE DEFERRABLE INITIALLY DEFERRED, i integer CONSTRAINT u2 UNIQUE DEFERRABLE INITIALLY IMMEDIATE, j integer UNIQUE NOT DEFERRABLE, k integer CONSTRAINT u3 UNIQUE)"]
+  end
+  
+  it "should handle :primary_key option with hash value for options for primary key constraint" do
+    @db.create_table(:cats) do
+      integer :id, :primary_key=>{:name=>:p1, :deferrable=>true}
+      integer :i, :primary_key=>{:name=>:p2, :deferrable=>:immediate}
+      integer :j, :primary_key=>{:deferrable=>false}
+      integer :k, :primary_key=>{:name=>:p3}
+    end
+    @db.sqls.must_equal ["CREATE TABLE cats (id integer CONSTRAINT p1 PRIMARY KEY DEFERRABLE INITIALLY DEFERRED, i integer CONSTRAINT p2 PRIMARY KEY DEFERRABLE INITIALLY IMMEDIATE, j integer PRIMARY KEY NOT DEFERRABLE, k integer CONSTRAINT p3 PRIMARY KEY)"]
+  end
+  
   it "should accept unsigned definition" do
     @db.create_table(:cats) do
       integer :value, :unsigned => true
@@ -572,7 +601,7 @@ describe "DB#create_table" do
   end
 
   it "should ignore errors if the database raises an error on an index creation statement and the :ignore_index_errors option is used" do
-    @db.define_singleton_method(:execute_ddl){|*a| raise Sequel::DatabaseError if /blah/.match(a.first); super(*a)}
+    @db.define_singleton_method(:execute_ddl){|*a| raise Sequel::DatabaseError if /blah/ =~ a.first; super(*a)}
     lambda{@db.create_table(:cats){Integer :id; index :blah; index :id}}.must_raise(Sequel::DatabaseError)
     @db.sqls.must_equal ['CREATE TABLE cats (id integer)']
     @db.create_table(:cats, :ignore_index_errors=>true){Integer :id; index :blah; index :id}
@@ -580,14 +609,14 @@ describe "DB#create_table" do
   end
 
   it "should not use savepoints around index creation if running inside a transaction if :ignore_index_errors option is used" do
-    @db.define_singleton_method(:execute_ddl){|*a| super(*a); raise Sequel::DatabaseError if /blah/.match(a.first)}
+    @db.define_singleton_method(:execute_ddl){|*a| super(*a); raise Sequel::DatabaseError if /blah/ =~ a.first}
     @db.transaction{@db.create_table(:cats, :ignore_index_errors=>true){Integer :id; index :blah; index :id}}
     @db.sqls.must_equal ["BEGIN", "CREATE TABLE cats (id integer)", "CREATE INDEX cats_blah_index ON cats (blah)", "CREATE INDEX cats_id_index ON cats (id)", "COMMIT"]
   end
 
   it "should use savepoints around index creation if running inside a transaction if :ignore_index_errors option is used and transactional schema modifications are supported" do
     @db.define_singleton_method(:supports_transactional_ddl?){true}
-    @db.define_singleton_method(:execute_ddl){|*a| super(*a); raise Sequel::DatabaseError if /blah/.match(a.first)}
+    @db.define_singleton_method(:execute_ddl){|*a| super(*a); raise Sequel::DatabaseError if /blah/ =~ a.first}
     @db.transaction{@db.create_table(:cats, :ignore_index_errors=>true){Integer :id; index :blah; index :id}}
     @db.sqls.must_equal ["BEGIN", "CREATE TABLE cats (id integer)", "SAVEPOINT autopoint_1", "CREATE INDEX cats_blah_index ON cats (blah)", "ROLLBACK TO SAVEPOINT autopoint_1", "SAVEPOINT autopoint_1", "CREATE INDEX cats_id_index ON cats (id)", "RELEASE SAVEPOINT autopoint_1", "COMMIT"]
   end
